"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const mysql = require("mysql");
const DBTransaction_1 = require("../db/DBTransaction");
const LogManager_1 = require("../log/LogManager");
const DBClient_1 = require("../db/DBClient");
const LOGGER = LogManager_1.LogManager.getLogger(__filename);
class MySQLTransaction extends DBTransaction_1.DBTransaction {
    runQueryInConnection(sql, bindsArr) {
        return new Promise((resolve, reject) => this.connection.query(sql, bindsArr, (err, rows) => {
            if (err) {
                LOGGER.error(err, `SQL error for ${sql}`);
                return reject(err);
            }
            return resolve(rows);
        }));
    }
    getTransactionBeginSQL() {
        return (this.isReadonly()) ? 'START TRANSACTION READ ONLY' : 'START TRANSACTION READ WRITE';
    }
}
exports.MySQLTransaction = MySQLTransaction;
class MySQLConnectionFactory {
    constructor(name, connectionConfig) {
        this.connConfig = connectionConfig;
        this.name = name;
    }
    create() {
        LOGGER.trace(`Creating new connection for pool ${this.name}`);
        const connection = mysql.createConnection(this.connConfig);
        return new Promise((resolve, reject) => connection.connect((err) => {
            if (err) {
                reject(err);
            }
            else {
                resolve(connection);
            }
        }));
    }
    destroy(connection) {
        LOGGER.trace(`Destroying connection for pool ${this.name}`);
        return new Promise((resolve, reject) => {
            connection.end((err) => {
                if (err) {
                    reject(err);
                }
                else {
                    resolve();
                }
            });
        });
    }
    validate(connection) {
        LOGGER.trace(`Validating connection for pool ${this.name}`);
        return new Promise((resolve, reject) => {
            connection.query('SELECT 1', (err, results) => {
                if (err) {
                    resolve(false);
                }
                resolve(true);
            });
        });
    }
}
/**
 * A MySQL client you can use to execute queries against MySQL
 */
class MySQLClient extends DBClient_1.DBClient {
    constructor(clientConfig) {
        super(clientConfig);
        this.enable57Mode = false;
    }
    async initialise() {
        this.enable57Mode = this.clientConfiguration.enable57Mode || false;
        await super.initialise();
    }
    getConnectionFactory(name, connectionConfig) {
        return new MySQLConnectionFactory(name, connectionConfig);
    }
    getNewDBTransaction(readonly, connectionPool) {
        return new MySQLTransaction(this.clientConfiguration.name, readonly, connectionPool);
    }
    getPingQuery() {
        return 'SELECT 1';
    }
    getDefaultConnectionConfig() {
        return {
            host: 'localhost',
            port: 3306,
            user: 'root',
            password: '',
            database: '',
            charset: 'UTF8',
        };
    }
}
exports.MySQLClient = MySQLClient;
//# sourceMappingURL=MySQLClient.js.map